Class: JazzModel::ChordScale
- Defined in:
- lib/jazz_model/chord_scale.rb
Overview
A relationship of one chord to one scale, with some other optional
information such as strength, representing the strength of the
relationships.
Associations
chord- Associated chord.mode- Associated scale mode.scale- Associated scale through mode.
Key Context
Delegates key to the associated chord to access key context through this relationship.
Class Method Summary collapse
Methods inherited from Base
Class Method Details
.specify(mode, strength = 1) ⇒ Object
23 24 25 26 27 28 |
# File 'lib/jazz_model/chord_scale.rb', line 23 def self.specify(mode, strength = 1) chord_scale = self.new chord_scale.mode = mode chord_scale.strength = strength chord_scale end |