Class: JazzModel::ScaleTone

Inherits:
Tone
  • Object
show all
Defined in:
lib/jazz_model/scale_tone.rb

Overview

Represents one tone in a scale.

Attributes

  • tone - A tone index from 0-11 representing the relative position of the tone within the chromatic scale.

  • letter_index - A 0-6 value representing the relative letter position, which helps to disambiguate theoretic values such as Eb and D#. See Key.

Key Context

key is delgated to chord to access the scale's key context.

Method Summary

Methods inherited from Base

load_definitions